xquery version "3.1";

module namespace kmg-register="https://mollenhauer-edition.de/ns/register";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace xhtml="http://www.w3.org/1999/xhtml";
declare namespace index="https://mollenhauer-edition.de/index";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";

declare function kmg-register:get-selector($node as node(), $model as map(*))
{
    let $selection := request:get-parameter("register", "")
    let $registers := ("persons", "art", "music")
    let $labels := map:merge((
        map:entry("persons", "Personen"),
        map:entry("art", "Kunstwerke"),
        map:entry("music", "Musikwerke")
    ))
    return
        for $register in $registers return
            element a {
                attribute href { "register.html?register=" || $register },
                if ($register eq $selection) then
                    attribute class { "selected" }
                else
                    (),
                $labels($register)
            }
};

declare function kmg-register:get-registers($node as node(), $model as map(*))
{
    let $selection := request:get-parameter("register", "")
    let $doc := doc($config:register || $selection || ".xml")
    (: for $doc in collection($config:register) :)
    return
        kmg-register:get-register($doc)
};

declare function kmg-register:get-register($doc as node()*)
{
    element noscript
    {
        element h2
        {
            switch ($doc/index:index/@type)
            case "person"
            return
                "Personenregister"
            case "art"
            return
                "Register der Kunstwerke"
            case "music"
            return
                "Register der Musikwerke"
            default
            return
                "Register"
        }
    },
    element ol
    {
        attribute class { "index-entries" },
        attribute data-indextype { $doc/index:index/@type },
        attribute role { "list" },
        kmg-register:get-entries($doc)
    }
};

declare function kmg-register:get-entries($doc as node()*)
{
    for $entry in kmg-register:sort-entries($doc)
    let $ref := $entry/@ref => substring-after(":")
    return
        element li
        {
            attribute class { "index-entry" },
            attribute data-letter { substring($entry/name/text(), 1, 1) => lower-case()},
            attribute data-target { $entry/@ref => substring-after(":") },
            element details
            {
                element summary {
                    attribute class { "index-entry-head" },
                    $entry/name/text()
                },
                element dl {
                    attribute class { "index-entry-body" },
                    element dt {
                        attribute class { "index-entry-label" },
                        "Name"
                    },
                    element dd {
                        attribute class { "index-entry-value" },
                        $entry/name/text()
                    },
                    if ($entry/composer) then
                        (element dt {
                            attribute class { "index-entry-label" },
                            "Komponist"
                        },
                        element dd {
                            attribute class { "index-entry-value" },
                            $entry/composer/text()
                        })
                    else
                        (),
                    if ($entry/birth) then
                        (element dt {
                            attribute class { "index-entry-label" },
                            "Geburtsdatum"
                        },
                        element dd {
                            attribute class { "index-entry-value" },
                            try {
                                xs:date($entry/birth/text()) => format-date("[D]. [MNn] [Y]", "de", (), ())
                            }
                            catch * {
                                $entry/birth/text()
                            }
                        })
                    else
                        (),
                    if ($entry/death) then
                        (element dt {
                            attribute class { "index-entry-label" },
                            "Sterbedatum"
                        },
                        element dd {
                            attribute class { "index-entry-value" },
                            try {
                                xs:date($entry/death/text()) => format-date("[D]. [MNn] [Y]", "de", (), ())
                            }
                            catch * {
                                $entry/death/text()
                            }
                        })
                    else
                        (),
                    element dt {
                        attribute class { "index-entry-label index-entry-source" },
                        "Quelle"
                    },
                    element dd {
                        attribute class { "index-entry-value" },
                        element a {
                            attribute href { "http://d-nb.info/gnd/" || $ref },
                            "http://d-nb.info/gnd/" || $ref,
                            " ",
                            element span {
                                attribute class { "fa fa-external-link-alt" }
                            }
                        }
                    }
                }
            }
        }
};

declare function kmg-register:sort-entries($doc as node()*)
{
    for $entry in $doc/index:index/index:body/index:entry
    where substring($entry/name/text(), 1, 1) ne "_"
    order by $entry/name/text()
    return
        $entry
};